==> MuSE-0.7pre1.tar.gz: MuSE-0.7pre1/outchannels.h <==
/* MuSE - Multiple Streaming Engine
 * Copyright (C) 2000-2002 Denis Roio aka jaromil <jaromil@dyne.org>
 *
 * This source code is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Public License as published 
 * by the Free Software Foundation; either version 2 of the License,
 * or (at your option) any later version.
 *
 * This source code is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * Please refer to the GNU Public License for more details.
 *
 * You should have received a copy of the GNU Public License along with
 * this source code; if not, write to:
 * Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef __OUTCHANNELS_H
#define __OUTCHANNELS_H

#include "generic.h"

extern "C" {
#include <lame/lame.h>
#include "libshout/shout.h"
}

#define ENCBUFFER_SIZE 131072 /* was 65536, but we have ram, is'nt it? */
#define ERRORMSG 128

class LameEnc {
 private:
  lame_global_flags *enc_flags;
  double prev;
  unsigned int bytes_accu;
  unsigned int bitrate;
 public:
  LameEnc();
  ~LameEnc();
  bool encode(short int *pcm, int num);
  void init(int nbps, int freq, int mode, int quality, int lowpass, int highpass);
  char *version();
  void flush();
  void close();
  unsigned int get_bitrate() { return bitrate; };
  int bps;
  bool initialized;
  char ver[128];
  unsigned char buffer[ENCBUFFER_SIZE];
  int encoded;
};

class IcecastOut {
private:
  void sync();

  shout_conn_t ice_conn;
  
  char errormsg[ERRORMSG];
  bool initialized;

public:
  IcecastOut();
  ~IcecastOut();

  bool start();
  void stop();
  bool set_server(char *naddress, int nport, char *npass, char *nmountpoint, int nbps,int nlogin);
  void set_meta(char *nname, char *nurl, char *ndesc);
  int send(unsigned char *buf, unsigned int enc);

  bool running;

  char ip[64];
  int port;
  char *pass;
  char *mountpoint;
  int bps;
  int login;
  char *name;
  char *url;
  char *description;
};

class Mp3fileOut {
 private:
  FILE *fd;
  char *filename;
  bool opened;

  bool syncmp3();

 public:
  Mp3fileOut();
  bool openmp3(char *file);
  int writemp3(unsigned char *buf, unsigned int enc);
  void closemp3();
  
  ~Mp3fileOut();
};

#endif

==> MuSE-0.7.1.tar.gz: MuSE-0.7.1/outchannels.h <==
/* MuSE - Multiple Streaming Engine
 * Copyright (C) 2000-2002 Denis Rojo aka jaromil <jaromil@dyne.org>
 *
 * This source code is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Public License as published 
 * by the Free Software Foundation; either version 2 of the License,
 * or (at your option) any later version.
 *
 * This source code is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * Please refer to the GNU Public License for more details.
 *
 * You should have received a copy of the GNU Public License along with
 * this source code; if not, write to:
 * Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef __OUTCHANNELS_H__
#define __OUTCHANNELS_H__

#include <profile.h>
#include <generic.h>

extern "C" {
#include <lame/lame.h>
#include <libshout/shout.h>
}

#define ENCBUFFER_SIZE 65536 // we have ram, isn't it?
#define ERRORMSG 128

class LameEnc : public Profile {

 private:
  lame_global_flags *enc_flags;
  double prev;
  unsigned int bytes_accu;
  unsigned int bitrate;

  bool encode_last;

 public:
  LameEnc();
  ~LameEnc();
  bool encode(short int *pcm, int num);
  void init();
  char *version();
  void flush();
  void flush_nogap();
  void close();
  
  /* this returns the size of the encoded audio in bytes */
  unsigned int get_bitrate() { return bitrate; };

  /* lame settings */
  bool apply_profile();
  int bps;
  int freq;
  int mode;
  int quality;
  int lowpass;
  int highpass;
  /* --- */

  bool initialized;
  char ver[128];
  unsigned char buffer[ENCBUFFER_SIZE];
  int encoded;
};

class IcecastOut : public Profile {
private:
  void sync();

  shout_conn_t ice_conn;
  
  char errormsg[ERRORMSG];
  bool initialized;

public:
  IcecastOut();
  ~IcecastOut();
  
  bool init();
  bool start();
  void stop();
  bool set_server(char *hostname);
  int send(unsigned char *buf, unsigned int enc);

  bool running;

  /* settings HERE */
  bool apply_profile();
  char ip[MAX_VALUE_SIZE];
  int port;
  char pass[MAX_VALUE_SIZE];
  char mount[MAX_VALUE_SIZE];
  int bps;
  int login;
  char name[MAX_VALUE_SIZE];
  char url[MAX_VALUE_SIZE];
  char desc[MAX_VALUE_SIZE];
  
};

class Mp3fileOut {
 private:
  FILE *fd;
  char *filename;
  bool opened;

  bool syncmp3();

 public:
  Mp3fileOut();
  bool openmp3(char *file);
  int writemp3(unsigned char *buf, unsigned int enc);
  void closemp3();
  
  ~Mp3fileOut();
};

#endif
